---
last_modified_on: "2020-07-13"
delivery_guarantee: "at_least_once"
component_title: "Journald"
description: "The Vector `journald` source ingests data through Systemd's Journald utility and outputs `log` events."
event_types: ["log"]
function_category: "collect"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+journald%22
operating_systems: ["Linux"]
sidebar_label: "journald|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/journald.rs
status: "beta"
title: "Journald Source"
unsupported_operating_systems: ["MacOS","Windows"]
---

import Alert from '@site/src/components/Alert';
import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `journald` source
ingests data through [Systemd's][urls.systemd] [Journald][urls.journald]
utility and outputs [`log`][docs.data-model.log] events.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/journald.md.erb
-->

## Requirements

<Alert icon={false} type="danger" className="list--icons list--icons--warnings">

* The [`journalctl`](#journalctl) binary is required, this is the interface Vector uses to retrieve JournalD logs. See the ["Communication Strategy" section][docs.sources.journald#communication-strategy] for more info.
* The Vector user must be part of the `systemd-journal` group in order to execute the [`journalctl`](#journalctl) binary. See the ["User Permissions" section][docs.sources.journald#user-permissions] for more info.

</Alert>

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[sources.my_source_id]
  type = "journald" # required
  current_boot_only = true # optional, default
  exclude_units = [] # optional, default
  include_units = [] # optional, default
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[sources.my_source_id]
  type = "journald" # required
  batch_size = 16 # optional, default
  current_boot_only = true # optional, default
  data_dir = "/var/lib/vector" # optional, no default
  exclude_units = [] # optional, default
  include_units = [] # optional, default
  journalctl_path = "journalctl" # optional, default
  remap_priority = false # optional, default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={false}
  defaultValue={16}
  enumValues={null}
  examples={[16]}
  groups={[]}
  name={"batch_size"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

### batch_size

The systemd journal is read in batches, and a checkpoint is set at the end of
each batch. This option limits the size of the batch.
 See [Checkpointing](#checkpointing) for more info.


</Field>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"current_boot_only"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### current_boot_only

Include only entries from the current boot.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/var/lib/vector"]}
  groups={[]}
  name={"data_dir"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### data_dir

The directory used to persist the journal checkpoint position. By default, the
global [`data_dir`](#data_dir) is used. Please make sure the Vector project has write
permissions to this dir.
 See [Checkpointing](#checkpointing) for more info.


</Field>
<Field
  common={true}
  defaultValue={[]}
  enumValues={null}
  examples={[["badservice","sysinit.target"]]}
  groups={[]}
  name={"exclude_units"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### exclude_units

The list of units names to exclude from monitoring. Unit names lacking a `"."`
will have `".service"` appended to make them a valid service unit name.



</Field>
<Field
  common={true}
  defaultValue={[]}
  enumValues={null}
  examples={[["ntpd","sysinit.target"]]}
  groups={[]}
  name={"include_units"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### include_units

The list of units names to monitor. If empty or not present, all units are
accepted. Unit names lacking a `"."` will have `".service"` appended to make
them a valid service unit name.



</Field>
<Field
  common={false}
  defaultValue={"journalctl"}
  enumValues={null}
  examples={["/usr/local/bin/journalctl"]}
  groups={[]}
  name={"journalctl_path"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### journalctl_path

The full path of the [`journalctl`](#journalctl) executable. If not set, Vector will search
the path for [`journalctl`](#journalctl).
 See [Communication strategy](#communication-strategy) for more info.


</Field>
<Field
  common={false}
  defaultValue={false}
  enumValues={null}
  examples={[false,true]}
  groups={[]}
  name={"remap_priority"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### remap_priority

If the record from journald contains a `PRIORITY` field, it will be remapped
into the equivalent syslog priority level name using the standard (abbreviated)
all-capitals names such as `EMERG` or `ERR`.



</Field>
</Fields>

## Fields

```javascript title="example log event"
{
  // ...
  "_SYSTEMD_UNIT": "ntpd.service",
  "host": "my.host.com",
  "message": "Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100",
  "timestamp": "2019-11-01T21:15:47+00:00"
  // ...
}
```

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[{"_SYSTEMD_UNIT":"ntpd.service"},{"_BOOT_ID":"124c781146e841ae8d9b4590df8b9231"}]}
  groups={[]}
  name={"`[record-key]`"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"*"}
  unit={null}
  warnings={[]}
  >

### `[record-key]`

Additional Journald fields are passed through as log fields.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["my.host.com"]}
  groups={[]}
  name={"host"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### host

The value of the journald `_HOSTNAME` field.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100"]}
  groups={[]}
  name={"message"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### message

The value of the journald `MESSAGE` field.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  groups={[]}
  name={"timestamp"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"timestamp"}
  unit={null}
  warnings={[]}
  >

### timestamp

The value of the journald `_SOURCE_REALTIME_TIMESTAMP` field.



</Field>
</Fields>

## Examples

Given the following input:

```text title="Example input"
reply from 192.168.1.2: offset -0.001791 delay 0.000176, next query 1500s
```

A log event will be output with the following structure:

```json title="Example log event"
{
  "timestamp": <2019-07-26T20:30:27.000443Z>,
  "message": "reply from 192.168.1.2: offset -0.001791 delay 0.000176, next query 1500s",
  "host": "lorien.example.com",
  "__REALTIME_TIMESTAMP": "1564173027000443",
  "__MONOTONIC_TIMESTAMP": "98694000446",
  "_BOOT_ID": "124c781146e841ae8d9b4590df8b9231",
  "SYSLOG_FACILITY": "3",
  "_UID": "0",
  "_GID": "0",
  "_CAP_EFFECTIVE": "3fffffffff",
  "_MACHINE_ID": "c36e9ea52800a19d214cb71b53263a28",
  "PRIORITY": "6",
  "_TRANSPORT": "stdout",
  "_STREAM_ID": "92c79f4b45c4457490ebdefece29995e",
  "SYSLOG_IDENTIFIER": "ntpd",
  "_PID": "2156",
  "_COMM": "ntpd",
  "_EXE": "/usr/sbin/ntpd",
  "_CMDLINE": "ntpd: [priv]",
  "_SYSTEMD_CGROUP": "/system.slice/ntpd.service",
  "_SYSTEMD_UNIT": "ntpd.service",
  "_SYSTEMD_SLICE": "system.slice",
  "_SYSTEMD_INVOCATION_ID": "496ad5cd046d48e29f37f559a6d176f8"
}
```

## How It Works

### Checkpointing

Vector checkpoints the journal position after every batch read. The size of
the batch is controlled via the [`batch_size`](#batch_size) option. Checkpointing ensures that
Vector resumes where it left off if restarted, preventing data from being read
twice. The checkpoint positions are stored in the data directory which is
specified via the [global [`data_dir`](#data_dir) option][docs.global-options#data_dir]
but can be overridden via the [`data_dir`](#data_dir) option in the `journald` source
directly.

### Communication strategy

To ensure the `journald` source works across all platforms, Vector interacts
with the Systemd journal via the [`journalctl`](#journalctl) command. This is accomplished by
spawning a [subprocess][urls.rust_subprocess] that Vector diligently interacts
with. If the [`journalctl`](#journalctl) command is not in the environment path you can
specify the exact location via the [`journalctl_path`](#journalctl_path) option. For more
information on this communication strategy please see
[issue #1473][urls.issue_1473].

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Non-ASCII messages

When `journald` has stored a message that is not strict ASCII,
`journalctl` will output it in an alternate format to prevent data
loss. Vector handles this alternate format by translating such messages
into UTF-8 in "lossy" mode, where characters that are not valid UTF-8
are replaced with the Unicode replacement character, `�`.

### User permissions

If you run Vector from a non-root user, you need to add that user to the
`systemd-journal` group.

For example, if the user is named `vector`, it can be done by running

```sh
usermod -aG systemd-journal vector
```

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.global-options#data_dir]: /docs/reference/global-options/#data_dir
[docs.sources.journald#communication-strategy]: /docs/reference/sources/journald/#communication-strategy
[docs.sources.journald#user-permissions]: /docs/reference/sources/journald/#user-permissions
[urls.issue_1473]: https://github.com/timberio/vector/issues/1473
[urls.journald]: https://www.freedesktop.org/software/systemd/man/systemd-journald.service.html
[urls.rust_subprocess]: https://docs.rs/subprocess
[urls.systemd]: https://systemd.io/
