---
last_modified_on: "2020-07-13"
title: Install Vector via Window Installer
sidebar_label: MSI
description: Install Vector through the Windows Installer
---

import ConfigExample from '@site/src/components/ConfigExample';
import DaemonDiagram from '@site/src/components/DaemonDiagram';
import Jump from '@site/src/components/Jump';
import Steps from '@site/src/components/Steps';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

Vector can be installed from an MSI package through the Windows Installer.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/setup/installation/package-managers/msi.md.erb
-->

## Install

<Tabs
  block={true}
  defaultValue="daemon"
  values={[{"label":"As a Daemon","value":"daemon"}]}>
<TabItem value="daemon">

The [daemon deployment strategy][docs.strategies#daemon] is designed for data
collection on a single host. Vector runs in the background, in its own process,
collecting _all_ data for that host.
Typically data is collected from a process manager, such as Journald via
Vector's [`journald` source][docs.sources.journald], but can be collected
through any of Vector's [sources][docs.sources].
The following diagram demonstrates how it works.

<DaemonDiagram
  platformName={null}
  sourceName={null}
  sinkName={null} />

---

<Tabs
  centered={true}
  className={"rounded"}
  defaultValue={"msi"}
  placeholder="Please choose an installation method..."
  select={false}
  size={null}
  values={[{"group":"Package managers","label":"MSI","value":"msi"}]}>
<TabItem value="msi">

<Steps headingDepth={3}>
<Tabs
  centered={true}
  className="rounded"
  defaultValue="x86_64"
  values={[{"label":"x86_64","value":"x86_64"}]}>

<TabItem value="x86_64">

1.  ### Download the Vector `.msi` file

    ```bat
    powershell Invoke-WebRequest https://packages.timber.io/vector/0.10.X/vector-x64.msi -OutFile vector-x64.msi
    ```

    [Looking for a specific version?][docs.package_managers.msi#versions]

2.  ### Install the Vector `.msi` package using `msiexec` command

    ```bat
    msiexec /i vector-x64.msi /quiet
    ```

3.  ### Navigate to the Vector directory

    ```bat
    cd "C:\Program Files\Vector"
    ```

4.  ### Configure Vector

    <ConfigExample
      format="toml"
      path={"config\\vector.toml"}
      sourceName={"file"}
      sinkName={null} />

5.  ### Start Vector

    ```bat
    .\bin\vector --config config\vector.toml
    ```

</TabItem>
</Tabs>
</Steps>

</TabItem>
</Tabs>
</TabItem>
</Tabs>

## Configuring

The Vector configuration file is placed in:

```text
%ProgramFiles%\Vector\config\vector.toml
```

A full spec is located at `%ProgramFiles%\Vector\config\vector.spec.toml` and examples are
located in `%ProgramFiles%\Vector\config\examples\*`. You can learn more about configuring
Vector in the [Configuration][docs.configuration] section.

## Deploying

How you deploy Vector is largely dependent on your use case and environment.
Please see the [deployment section][docs.deployment] for more info on how to
deploy Vector.

## Administering

Vector can be managed as a [Windows Service][urls.windows_service]:

<Jump to="/docs/administration/">Administration</Jump>

## Uninstalling

```bat
msiexec /x {7FAD6F97-D84E-42CC-A600-5F4EC3460FF5} /quiet
```

## Updating

Follow the [install](#install) steps again, downloading the latest version of
Vector.

## Package

### Architectures

Vector's MSI packages only support the X86_64 architecture.

### Versions

Vector's MSI packages can be downloaded with the following URLs. Note that
Vector maintains special URLS that are automatically updated whenever Vector is
[released][urls.vector_releases]:

<Tabs
  className="mini"
  defaultValue="x86_64"
  values={[{"label":"x86_64","value":"x86_64"}]}>
<TabItem value="x86_64">

| Version          | URL                                                                                               |
|:-----------------|:--------------------------------------------------------------------------------------------------|
| Latest major     | `https://packages.timber.io/vector/latest/vector-x64.msi`               |
| Latest minor     | `https://packages.timber.io/vector/<MAJOR>.X/vector-x64.msi`            |
| Latest patch     | `https://packages.timber.io/vector/<MAJOR.MINOR>.X/vector-x64.msi`      |
| Specific version | `https://packages.timber.io/vector/<MAJOR.MINOR.PATCH>/vector-x64.msi`  |
| Latest nightly   | `https://packages.timber.io/vector/nightly/latest/vector-x64.msi`       |
| Specific nightly | `https://packages.timber.io/vector/nightly/<YYYY-MM-DD>/vector-x64.msi` |

</TabItem>
</Tabs>


### Source Files

Vector's MSI source files are located in
[Vector's repo][urls.vector_msi_source_files].

[docs.configuration]: /docs/setup/configuration/
[docs.deployment]: /docs/setup/deployment/
[docs.package_managers.msi#versions]: /docs/setup/installation/package-managers/msi/#versions
[docs.sources.journald]: /docs/reference/sources/journald/
[docs.sources]: /docs/reference/sources/
[docs.strategies#daemon]: /docs/setup/deployment/strategies/#daemon
[urls.vector_msi_source_files]: https://github.com/timberio/vector/tree/master/distribution/msi
[urls.vector_releases]: https://vector.dev/releases/latest/
[urls.windows_service]: https://docs.microsoft.com/en-us/powershell/module/microsoft.powershell.management/new-service
