---
last_modified_on: "2020-07-13"
title: Install Vector On Docker
sidebar_label: Docker
description: Install Vector on the Docker platform
source_url: https://github.com/timberio/vector/tree/master/distribution/docker
---

import CodeExplanation from '@site/src/components/CodeExplanation';
import ConfigExample from '@site/src/components/ConfigExample';
import DaemonDiagram from '@site/src/components/DaemonDiagram';
import ServiceDiagram from '@site/src/components/ServiceDiagram';
import SidecarDiagram from '@site/src/components/SidecarDiagram';
import Steps from '@site/src/components/Steps';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

Vector maintains the [`timberio/vector` Docker images][urls.docker_hub_vector]
available on [Docker Hub][urls.docker_hub_vector] which come pre-installed
with Vector and any recommended system dependencies. These images are available
for x86_64, ARM64, and ARMv7
architectures.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/setup/installation/platforms/docker.md.erb
-->

## Install

<Tabs
  block={true}
  defaultValue="daemon"
  values={[{"label":"As a Daemon","value":"daemon"},{"label":"As a Sidecar","value":"sidecar"},{"label":"As a Service","value":"service"}]}>
<TabItem value="daemon">

The [daemon deployment strategy][docs.strategies#daemon] is designed for data
collection on a single host. Vector runs in the background, in its own process,
collecting _all_ data for that host.
Typically data is collected from a process manager, such as Journald via
Vector's [`journald` source][docs.sources.journald], but can be collected
through any of Vector's [sources][docs.sources].
The following diagram demonstrates how it works.

<DaemonDiagram
  platformName={"docker"}
  sourceName={null}
  sinkName={null} />

---

<Tabs
  centered={true}
  className={"rounded"}
  defaultValue={"docker-cli"}
  placeholder="Please choose an installation method..."
  select={false}
  size={null}
  values={[{"group":"Platforms","label":"Docker CLI","value":"docker-cli"},{"group":"Platforms","label":"Docker Compose","value":"docker-compose"}]}>
<TabItem value="docker-cli">

<Steps headingDepth={3}>
<ol>
<li>

### Configure Vector

<ConfigExample
  format="toml"
  path={"/etc/vector/vector.toml"}
  sourceName={"docker"}
  sinkName={null} />

</li>
<li>

### Start the Vector container

```bash
docker run \
  -v $PWD/vector.toml:/etc/vector/vector.toml:ro \
  -v /var/run/docker.sock:/var/run/docker.sock \
  timberio/vector:latest-alpine
```

<CodeExplanation>

* The `-v $PWD/vector.to...` flag passes your custom configuration to Vector.
* The `-v /var/run/docke...` flag ensures that Vector has access to the Docker API.
* The `timberio/vector:latest-alpine` is the default image we've chosen, you are welcome to use [other image variants][docs.platforms.docker#variants].

</CodeExplanation>

That's it! Simple and to the point. Hit `ctrl+c` to exit.

</li>
</ol>
</Steps>

</TabItem>
<TabItem value="docker-compose">

compose!

</TabItem>
</Tabs>
</TabItem>
<TabItem value="sidecar">

The [sidecar deployment strategy][docs.strategies#sidecar] is designed to
collect data from a _single_ service. Vector has a tight 1 to 1 coupling with
each service. Typically data is collected by tailing local files via Vector's
[`file` source][docs.sources.file], but can be collected through any of Vector's
[sources][docs.sources]. The following diagram demonstrates how it works.

<SidecarDiagram
  platformName={"docker"}
  sourceName={null}
  sinkName={null} />

---

<Tabs
  centered={true}
  className={"rounded"}
  defaultValue={"docker-cli"}
  placeholder="Please choose an installation method..."
  select={false}
  size={null}
  values={[{"group":"Platforms","label":"Docker CLI","value":"docker-cli"},{"group":"Platforms","label":"Docker Compose","value":"docker-compose"}]}>
<TabItem value="docker-cli">

<Steps headingDepth={3}>
<ol>
<li>

### Configure Vector

<ConfigExample
  format="toml"
  path={"/etc/vector/vector.toml"}
  sourceName={"file"}
  sinkName={null} />

</li>
<li>

### Start the Vector container

```bash
docker run \
  -v $PWD/vector.toml:/etc/vector/vector.toml:ro \
  -v /var/log \
  timberio/vector:latest-alpine
```

<CodeExplanation>

* The `-v $PWD/vector.to...` flag passes your custom configuration to Vector.
* The `-v /var/log` flag ensures that Vector has access to your app's logging directory, adjust as necessary.
* The `timberio/vector:latest-alpine` is the default image we've chosen, you are welcome to use [other image variants][docs.platforms.docker#variants].

</CodeExplanation>

That's it! Simple and to the point. Hit `ctrl+c` to exit.

</li>
</ol>
</Steps>

</TabItem>
<TabItem value="docker-compose">

compose!

</TabItem>
</Tabs>
</TabItem>
<TabItem value="service">

The [service deployment strategy][docs.strategies#service] treats Vector like a
separate service. It is designed to receive data from an upstream source and
fan-out to one or more destinations.
Typically, upstream sources are other Vector instances sending data via the
[`vector` sink][docs.sinks.vector], but can be collected through any of Vector's
[sources][docs.sources].
The following diagram demonstrates how it works.

<ServiceDiagram
  platformName={"docker"}
  sourceName={null}
  sinkName={null} />

---

<Tabs
  centered={true}
  className={"rounded"}
  defaultValue={"docker-cli"}
  placeholder="Please choose an installation method..."
  select={false}
  size={null}
  values={[{"group":"Platforms","label":"Docker CLI","value":"docker-cli"},{"group":"Platforms","label":"Docker Compose","value":"docker-compose"}]}>
<TabItem value="docker-cli">

<Steps headingDepth={3}>
<ol>
<li>

### Configure Vector

<ConfigExample
  format="toml"
  path={"/etc/vector/vector.toml"}
  sourceName={"vector"}
  sinkName={null} />

</li>
<li>

### Start the Vector container

```bash
docker run \
  -v $PWD/vector.toml:/etc/vector/vector.toml:ro \
  -p 9000:9000 \
  timberio/vector:latest-alpine
```

<CodeExplanation>

* The `-v $PWD/vector.to...` flag passes your custom configuration to Vector.
* The `-p 9000:9000` flag ensures that port 9000 is exposed for network communication.
* The `timberio/vector:latest-alpine` is the default image we've chosen, you are welcome to use [other image variants][docs.platforms.docker#variants].

</CodeExplanation>

That's it! Simple and to the point. Hit `ctrl+c` to exit.

</li>
</ol>
</Steps>

</TabItem>
<TabItem value="docker-compose">

compose!

</TabItem>
</Tabs>
</TabItem>
</Tabs>

## Configuring

As shown above, you can pass a custom
[Vector configuration file][docs.configuration] via the `-v` flag. You'll want
to do this since the
[default `/etc/vector/vector.toml` configuration file][urls.default_configuration]
doesn't do anything.

## Deploying

How you deploy Vector is largely dependent on your use case and environment.
Please see the [deployment section][docs.deployment] for more info on how to
deploy Vector.

## Updating

Simply run with newer version in the tag:

```bash
docker pull timberio/vector:X.X.X-alpine && \
  docker run timberio/vector:X.X.X-alpine
```

See the [variants](#variants) and [versions](#versions) sections to choose
the appropriate image for your use case.

## Images

### Variants

#### alpine

This image is based on the [`alpine` Docker image][urls.docker_alpine], which is
a Linux distribution built around musl libc and BusyBox. It is considerably
smaller in size than other Docker images and statically links libraries. This
is the image we recommend due to it's small size and reliability.

```bash
docker run timberio/vector:0.10.0-alpine
```

#### debian

This image is based on the [`debian-slim` image][urls.docker_debian],
which is a smaller, more compact variant of the [`debian` image][urls.docker_debian].

```bash
docker run timberio/vector:0.10.0-debian
```

### Architectures

Vector's images are multi-arch and support the
x86_64, ARM64, and ARMv7 architectures.
Docker handles this transparently for you.

### Versions

Vector's Docker images can be downloaded with the following tags. Note that
Vector maintains special tags that are automatically updated whenever Vector is
[released][urls.vector_releases]:

| Version          | URL                                                      |
|:-----------------|:---------------------------------------------------------|
| Latest major     | `timberio/vector:latest-alpine`               |
| Latest minor     | `timberio/vector:<MAJOR>.X-alpine`            |
| Latest patch     | `timberio/vector:<MAJOR.MINOR>.X-alpine`      |
| Specific version | `timberio/vector:<MAJOR.MINOR.PATCH>-alpine`  |
| Latest nightly   | `timberio/vector:nightly-alpine`              |
| Specific nightly | `timberio/vector:nightly-<YYYY-MM-DD>-alpine` |

### Source Files

Vector's Docker source files are located
[in it's Github repo][urls.vector_docker_source_files].

[docs.configuration]: /docs/setup/configuration/
[docs.deployment]: /docs/setup/deployment/
[docs.platforms.docker#variants]: /docs/setup/installation/platforms/docker/#variants
[docs.sinks.vector]: /docs/reference/sinks/vector/
[docs.sources.file]: /docs/reference/sources/file/
[docs.sources.journald]: /docs/reference/sources/journald/
[docs.sources]: /docs/reference/sources/
[docs.strategies#daemon]: /docs/setup/deployment/strategies/#daemon
[docs.strategies#service]: /docs/setup/deployment/strategies/#service
[docs.strategies#sidecar]: /docs/setup/deployment/strategies/#sidecar
[urls.default_configuration]: https://github.com/timberio/vector/blob/master/config/vector.toml
[urls.docker_alpine]: https://hub.docker.com/_/alpine
[urls.docker_debian]: https://hub.docker.com/_/debian
[urls.docker_hub_vector]: https://hub.docker.com/r/timberio/vector
[urls.vector_docker_source_files]: https://github.com/timberio/vector/tree/master/distribution/docker
[urls.vector_releases]: https://vector.dev/releases/latest/
