---
last_modified_on: "2020-07-13"
$schema: "/.meta/.schemas/guides.json"
title: Monitoring Vector
description: How to monitoring and observe Vector in production
series_position: 4
author_github: https://github.com/binarylogic
tags: ["type: guide", "domain: observability"]
---

import Alert from '@site/src/components/Alert';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

Now that you've deployed Vector you'll want to make sure it's healthy and
performing. This guide will cover how to monitor and observe Vector.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/guides/getting-started/monitoring.md.erb
-->

## Metrics

<Alert type="info">

Internal observability of Vector is being _actively_ developed and is on our
[1.0 roadmap][urls.vector_roadmap]. You can expect a new `internal_metrics`
[source][docs.sources] that will allow you to run internal Vector metrics
through a Vector pipeline.

</Alert>

## Logs

Vector writes all logs to `STDOUT`, accessing these logs is dependent on how
you installed Vector.

<Tabs
  block={false}
  centered={true}
  groupId="interfaces"
  placeholder="How did you install Vector?"
  select={true}
  size={"lg"}
  values={[{"group":"Package managers","label":"DPKG","value":"dpkg"},{"group":"Platforms","label":"Docker CLI","value":"docker-cli"},{"group":"Platforms","label":"Docker Compose","value":"docker-compose"},{"group":"Package managers","label":"Homebrew","value":"homebrew"},{"group":"Package managers","label":"MSI","value":"msi"},{"group":"Package managers","label":"Nix","value":"nix"},{"group":"Package managers","label":"RPM","value":"rpm"},{"group":"Nones","label":"Vector CLI","value":"vector-cli"}]}>
<TabItem value="dpkg">

The Vector DEB package installs Vector as a Systemd service. Logs can be
accessed through the `journalctl` utility:

```bash
sudo journalctl -fu vector
```

</TabItem>
<TabItem value="docker-cli">

If you've started Vector through the `docker` CLI you can access Vector's logs
via the `docker logs` command. First, find the Vector container ID:

```bash
docker ps | grep vector
```

Copy Vector's container ID and use it to tail the logs:

```bash
docker logs -f <container-id>
```

</TabItem>
<TabItem value="docker-compose">

If you started Vector through Docker compose you can use the following command
to access Vector's logs:

```bash
docker-compose logs -f vector
```

Replace `vector` with the name of Vector's service if it is not called `vector`.

</TabItem>
<TabItem value="homebrew">

When Vector is started through Homebrew the logs are automatically routed to
`/usr/local/var/log/vector.log`. You can tail them with the `tail` utility:

```bash
tail -f /usr/local/var/log/vector.log
```

</TabItem>
<TabItem value="msi">

The Vector MSI package does not install Vector into a proces manager. Therefore,
Vector must be started by executing the Vector binary directly. Vector's logs
are written to `STDOUT`. You are in charge of routing `STDOUT`, and this
determines how you access Vector's logs.

</TabItem>
<TabItem value="nix">

The Vector Nix package does not install Vector into a proces manager. Therefore,
Vector must be started by executing the Vector binary directly. Vector's logs
are written to `STDOUT`. You are in charge of routing `STDOUT`, and this
determines how you access Vector's logs.

</TabItem>
<TabItem value="rpm">

The Vector RPM package installs Vector as a Systemd service. Logs can be
accessed through the `journalctl` utility:

```bash
sudo journalctl -fu vector
```

</TabItem>
<TabItem value="vector-cli">

If you are starting Vector directly from the Vector CLI then all logs will be
written to `STDOUT`. You are in charge of routing `STDOUT`, and this determines
how you access Vector's logs.

</TabItem>
</Tabs>

## What To Expect

How Vector performs is largely dependent on your configuration, hardware,
data shape, and volume. No two deployments perform the same! With that said,
Vector should perform well in most cases. The following sections provide general
references points for what you can expect in production.

### Benchmarks

Our [performance benchmarks][urls.vector_performance] are the best point of
reference when understanding how Vector performs. This data should give you a
general idea of Vector's performance under different scenarios.

### Throughput

Vector should be relatively high throughput. One a 4 core machine should produce
throughput between 20mb/s to 100mb/s depending on your data and configuration.

### CPU

Vector is mostly CPU bound and benefits from more cores and CPU efficient
machines.

### Memory

Vector should use very little memory. For average pipelines Vector uses around
200mb, but this can vary widely dependind on your configuraton.

[docs.sources]: /docs/reference/sources/
[urls.vector_performance]: https://vector.dev/#performance
[urls.vector_roadmap]: https://github.com/timberio/vector/milestones?direction=asc&sort=due_date&state=open
